@@ -10,7 +10,7 @@ def scheduleSession(args):
         print('NWBORG ERROR: not in the uppermost folder of an nwborg project.')
         return
     
-    session_skeletons = SAPOFTO.SAPOFTO(key='sessionskeletons',filename='sessionskeletons.org')
+    session_skeletons = SAPOFTO.SAPOFTO(key='session_skeletons',filename='session_skeletons.org')
     print('args:', args)
     session_archetype = args[0]
     skeleton = session_skeletons[session_archetype]
@@ -75,7 +75,7 @@ def scheduleSession(args):
 
 
 def generateSessionCode(args):
-    session_skeletons = SAPOFTO.SAPOFTO(key='sessionskeletons',filename='sessionskeletons.org')
+    session_skeletons = SAPOFTO.SAPOFTO(key='session_skeletons',filename='session_skeletons.org')
     print('args:', args)
     session_archetype = args[0]
     skeleton = session_skeletons[session_archetype]
@@ -121,7 +121,7 @@ def generateSessionCode(args):
     dotnwborglab.populatePrototype(prototype_parameters)
     session_code.appendLine("#!!! This file was automatically generated by nwborg !!!")
     session_code.appendLine("# Code generated primarily from the parsing of: ")
-    session_code.appendLine("#   - sessionskeletons.org")
+    session_code.appendLine("#   - session_skeletons.org")
     for sensor in sensor_files:
         session_code.appendLine("#   - sensors/" + str(sensor) + ".org")
 
@@ -217,7 +217,7 @@ def quickstartSession(args, session_dict=None, subject_id_dict=None, session_id=
         print('NWBORG ERROR: not in the uppermost folder of an nwborg project.')
         return
     
-    session_skeletons = SAPOFTO.SAPOFTO(key='SKELETON',filename='sessionskeletons.org')
+    session_skeletons = SAPOFTO.SAPOFTO(key='SKELETON',filename='session_skeletons.org')
     print('args:', args)
     session_archetype = args[0]
     skeleton = session_skeletons[session_archetype]
